@@ -132,9 +132,8 @@ static unsigned long int time_seed(void) {
 
 #ifdef HAVE_GETTIMEOFDAY
 	struct timeval tv;
-	struct timezone tz;
 
-	if (gettimeofday(&tv, &tz) == 0)
+	if (gettimeofday(&tv, NULL) == 0)
 		return (unsigned long int) tv.tv_sec * 1000000 + tv.tv_usec;
 	else
 		return (unsigned long int) time(NULL);
