@@ -12,15 +12,17 @@ summary(x$var1.pred - meuse.grid$idw)
 spplot(meuse.grid["idw"],col.regions=bpy.colors())
 v = vgm(1, "Exp", 500)
 # test sk:
-meuse.grid$sk <- krige0(zinc~1, meuse, meuse.grid, v, beta = 500)
+x0 <- krige0(zinc~1, meuse, meuse.grid, v, beta = 500, computeVar = TRUE)
 x <- krige(zinc~1, meuse, meuse.grid, v, beta = 500)
-summary(x$var1.pred - meuse.grid$sk)
-spplot(meuse.grid["sk"],col.regions=bpy.colors())
+summary(x$var1.pred - x0$pred)
+summary(x$var1.var - x0$var)
 # test ok:
-meuse.grid$ok <- krige0(zinc~1, meuse, meuse.grid, v)
+x0 <- krige0(zinc~1, meuse, meuse.grid, v, computeVar = TRUE)
 x <- krige(zinc~1, meuse, meuse.grid, v)
-summary(x$var1.pred - meuse.grid$ok)
+summary(x$var1.pred - x0$pred)
+summary(x$var1.var - x0$var)
 # test uk:
-meuse.grid$uk <- krige0(zinc~sqrt(dist), meuse, meuse.grid, v)
+x0 <- krige0(zinc~sqrt(dist), meuse, meuse.grid, v, computeVar = TRUE)
 x <- krige(zinc~sqrt(dist), meuse, meuse.grid, v)
-summary(x$var1.pred - meuse.grid$uk)
+summary(x$var1.pred - x0$pred)
+summary(x$var1.var - x0$var)
